@@ -24,7 +24,7 @@
 #include <libgnome/gnome-macros.h>
 
 /* Must be before all other gnome includes!! */
-#include "gnome-i18nP.h"
+#include <glib/gi18n-lib.h>
 
 #include "gnome-druid.h"
 #include "gnome-uidefs.h"
